@@ -1,3 +1,3 @@
 if __name__ == '__main__':
-    from . import main
+    from .util import main
     main()
