@@ -1,7 +1,7 @@
 from sys import stderr
 from time import sleep
 import requests
-from loguru import logger
+from logging import warning, error, debug
 
 from manga_py.fs import get_temp_path, make_dirs, remove_file_query_params, basename, path_join, dirname, file_size
 from .multi_threads import MultiThreads
@@ -45,7 +45,7 @@ class Http(Request):
             now_try_count += 1
             response = self.requests(url, method=method, timeout=60, allow_redirects=True)
             if response.status_code >= 400:
-                logger.error('\nERROR! Code {}\nUrl: {}\n'.format(
+                error('\nERROR! Code {}\nUrl: {}\n'.format(
                     response.status_code,
                     url,
                 ))
@@ -65,7 +65,7 @@ class Http(Request):
             url = self.normalize_uri(url)
             self._download(file_name, url, method)
         except OSError as ex:
-            logger.error(ex)
+            error(ex)
             return False
         return True
 
@@ -83,6 +83,7 @@ class Http(Request):
             mode = 'Retry'
             if r >= self.count_retries:
                 mode = 'Skip image'
+                warning('%s: %s' % (mode, url))
             callable(callback) and callback(text=mode)
         return False
 
@@ -98,9 +99,9 @@ class Http(Request):
         result = self._download_one_file_helper(url, dst, callback, success_callback, callback_args)
         if result is None and not self.mute:
             self.has_error = True  # issue 161
-            logger.warning('\nWarning: 0 bit image downloaded, please check for redirection or broken content')
+            warning('\nWarning: 0 bit image downloaded, please check for redirection or broken content')
             if ~idx:
-                logger.warning('Broken url: %s\nPage idx: %d' % (url, (1 + idx)), file=stderr)
+                warning('Broken url: %s\nPage idx: %d' % (url, (1 + idx)), file=stderr)
         return result
 
     def normalize_uri(self, uri, referer=None):
