@@ -1,7 +1,5 @@
 from argparse import ArgumentParser
 
-from loguru import logger
-
 from .info import Info
 from .providers import get_provider
 
@@ -42,6 +40,5 @@ class Parser:
         self.provider.set_quest_callback(quest)
         self.provider.set_quest_password_callback(quest_password)
 
-    @logger.catch
     def start(self):
         self.provider.process(self.params['url'], self.params)
