@@ -4,13 +4,6 @@ import re
 
 
 class Std:
-    _vol_fill = False
-
-    def get_archive_name(self) -> str:
-        idx = self.get_chapter_index()
-        self._vol_fill = True
-        return self.normal_arc_name({'vol': idx.split('-')})
-
     def _elements(self, selector, content=None) -> list:
         if not content:
             content = self.content
@@ -60,8 +53,14 @@ class Std:
             url = self.get_url()
         return re.search(selector, url).group(1)
 
-    def _get_content(self, tpl) -> str:
-        return self.http_get(tpl.format(self.domain, self.manga_name))
+    def _get_content(self, tpl, **kwargs) -> str:
+        try:
+            _kw = kwargs.copy()
+            _kw.setdefault('domain', self.domain)
+            _kw.setdefault('manga_name', self.manga_name)
+            return self.http_get(tpl.format(**_kw))
+        except Exception:
+            return self.http_get(tpl.format(self.domain, self.manga_name))
 
     def _base_cookies(self, url=None):
         if url is None:
@@ -76,58 +75,6 @@ class Std:
         )
         return self.http().normalize_uri(url.group(1))
 
-    @property
-    def manga_name(self) -> str:
-        name = self._storage.get('manga_name', None)
-        if name is None:
-            name = self.get_manga_name()
-        return name
-
-    def normal_arc_name(self, idx):
-        if isinstance(idx, str):
-            idx = [idx]
-        if isinstance(idx, list):
-            self._vol_fill = True
-            return self.__normal_name_list(idx)
-        if isinstance(idx, dict):
-            return self.__normal_name_dict(idx)
-        raise DeprecationWarning('Wrong arc name type: %s' % type(idx))
-
-    @staticmethod
-    def __fill(var, fmt: str = '-{}'):
-        if isinstance(var, str):
-            var = [var]
-        return (fmt * len(var)).format(*var).lstrip('-')
-
-    def __normal_name_list(self, idx: list):
-        fmt = 'vol_{:0>3}'
-        if len(idx) > 1:
-            fmt += '-{}' * (len(idx) - 1)
-        elif self._vol_fill and self._zero_fill:
-            idx.append('0')
-            fmt += '-{}'
-        return fmt.format(*idx)
-
-    def __normal_name_dict(self, idx: dict):
-        vol = idx.get('vol', None)
-        ch = idx.get('ch', None)
-        result = ''
-        if vol:
-            if isinstance(vol, str):
-                vol = [vol]
-            result = self.__normal_name_list(vol)
-        if ch:
-            result += '-ch_' + self.__fill(ch)
-
-        if self._with_manga_name:
-            name = self._params.get('name', '')
-            if not len(name):
-                name = self.manga_name
-
-            result = '%s-%s' % (name, result)
-
-        return result
-
     def text_content(self, content, selector, idx: int = 0, strip: bool = True):
         doc = self.document_fromstring(content, selector)
         if not doc:
